@@ -26,7 +26,7 @@ async def get_devices(
     )
     api_devices = await api.get_devices()
 
-    devices = list()
+    devices = []
     for api_device in api_devices:
         devices.append(await Device.create_device(
             api,
@@ -63,7 +63,8 @@ async def get_aws_devices(
             type_name=device["type"],
         )
 
-
-    devices = list(map(create_device, api_devices))
-
-    return (api, devices)
+    devices = map(create_device, api_devices)
+    return (
+        api,
+        list(devices)
+    )
